import * as fastComponents from '@microsoft/fast-components';
import { html, ref, repeat } from '@microsoft/fast-element';
const categories = [
    {
        title: 'Fill',
        subcategories: [
            {
                title: 'Fill Colour',
                tokens: [
                    {
                        name: 'fillColor',
                        cssProperty: '--fill-color',
                    },
                ],
            },
            {
                title: 'Accent Fill',
                tokens: [
                    {
                        name: 'accentFillRest',
                        cssProperty: '--accent-fill-rest',
                    },
                    {
                        name: 'accentFillHover',
                        cssProperty: '--accent-fill-hover',
                    },
                    {
                        name: 'accentFillActive',
                        cssProperty: '--accent-fill-active',
                    },
                    {
                        name: 'accentFillFocus',
                        cssProperty: '--accent-fill-focus',
                    },
                ],
            },
            {
                title: 'Neutral Fill',
                tokens: [
                    {
                        name: 'neutralFillRest',
                        cssProperty: '--neutral-fill-rest',
                    },
                    {
                        name: 'neutralFillHover',
                        cssProperty: '--neutral-fill-hover',
                    },
                    {
                        name: 'neutralFillActive',
                        cssProperty: '--neutral-fill-active',
                    },
                    {
                        name: 'neutralFillFocus',
                        cssProperty: '--neutral-fill-focus',
                    },
                ],
            },
            {
                title: 'Neutral Fill Input',
                tokens: [
                    {
                        name: 'neutralFillInputRest',
                        cssProperty: '--neutral-fill-input-rest',
                    },
                    {
                        name: 'neutralFillInputHover',
                        cssProperty: '--neutral-fill-input-hover',
                    },
                    {
                        name: 'neutralFillInputActive',
                        cssProperty: '--neutral-fill-input-active',
                    },
                    {
                        name: 'neutralFillInputFocus',
                        cssProperty: '--neutral-fill-input-focus',
                    },
                ],
            },
            {
                title: 'Neutral Fill Stealth',
                tokens: [
                    {
                        name: 'neutralFillStealthRest',
                        cssProperty: '--neutral-fill-stealth-rest',
                    },
                    {
                        name: 'neutralFillStealthHover',
                        cssProperty: '--neutral-fill-stealth-hover',
                    },
                    {
                        name: 'neutralFillStealthActive',
                        cssProperty: '--neutral-fill-stealth-active',
                    },
                    {
                        name: 'neutralFillStealthFocus',
                        cssProperty: '--neutral-fill-stealth-focus',
                    },
                ],
            },
            {
                title: 'Neutral Fill Strong',
                tokens: [
                    {
                        name: 'neutralFillStrongRest',
                        cssProperty: '--neutral-fill-strong-rest',
                    },
                    {
                        name: 'neutralFillStrongHover',
                        cssProperty: '--neutral-fill-strong-hover',
                    },
                    {
                        name: 'neutralFillStrongActive',
                        cssProperty: '--neutral-fill-strong-active',
                    },
                    {
                        name: 'neutralFillStrongFocus',
                        cssProperty: '--neutral-fill-strong-focus',
                    },
                ],
            },
        ],
    },
    {
        title: 'Foreground',
        subcategories: [
            {
                title: 'Neutral Foreground',
                tokens: [
                    {
                        name: 'neutralForegroundRest',
                        cssProperty: '--neutral-foreground-rest',
                    },
                    {
                        name: 'neutralForegroundHint',
                        cssProperty: '--neutral-foreground-hint',
                    },
                ],
            },
            {
                title: 'Accent Foreground',
                tokens: [
                    {
                        name: 'accentForegroundRest',
                        cssProperty: '--accent-foreground-rest',
                    },
                    {
                        name: 'accentForegroundHover',
                        cssProperty: '--accent-foreground-hover',
                    },
                    {
                        name: 'accentForegroundActive',
                        cssProperty: '--accent-foreground-active',
                    },
                    {
                        name: 'accentForegroundFocus',
                        cssProperty: '--accent-foreground-focus',
                    },
                ],
            },
            {
                title: 'Foreground on Accent',
                tokens: [
                    {
                        name: 'foregroundOnAccentRest',
                        cssProperty: '--foreground-on-accent-rest',
                    },
                    {
                        name: 'foregroundOnAccentHover',
                        cssProperty: '--foreground-on-accent-hover',
                    },
                    {
                        name: 'foregroundOnAccentActive',
                        cssProperty: '--foreground-on-accent-active',
                    },
                    {
                        name: 'foregroundOnAccentFocus',
                        cssProperty: '--foreground-on-accent-focus',
                    },
                ],
            },
            {
                title: 'Foreground on accent large',
                tokens: [
                    {
                        name: 'foregroundOnAccentRestLarge',
                        cssProperty: '--foreground-on-accent-rest-large',
                    },
                    {
                        name: 'foregroundOnAccentHoverLarge',
                        cssProperty: '--foreground-on-accent-hover-large',
                    },
                    {
                        name: 'foregroundOnAccentActiveLarge',
                        cssProperty: '--foreground-on-accent-active-large',
                    },
                    {
                        name: 'foregroundOnAccentFocusLarge',
                        cssProperty: '--foreground-on-accent-focus-large',
                    },
                ],
            },
        ],
    },
    {
        title: 'Stroke',
        subcategories: [
            {
                title: 'Focus Stroke',
                tokens: [
                    {
                        name: 'focusStrokeOuter',
                        cssProperty: '--focus-stroke-outer',
                    },
                    {
                        name: 'focusStrokeInner',
                        cssProperty: '--focus-stroke-inner',
                    },
                ],
            },
            {
                title: 'Neutral Stroke',
                tokens: [
                    {
                        name: 'neutralStrokeRest',
                        cssProperty: '---neutral-stroke-rest',
                    },
                    {
                        name: 'neutralStrokeHover',
                        cssProperty: '--neutral-stroke-hover',
                    },
                    {
                        name: 'neutralStrokeActive',
                        cssProperty: '--neutral-stroke-active',
                    },
                    {
                        name: 'neutralStrokeFocus',
                        cssProperty: '--neutral-stroke-focus',
                    },
                ],
            },
            {
                title: 'Neutral stroke divider',
                tokens: [
                    {
                        name: 'neutralStrokeDividerRest',
                        cssProperty: '--neutral-stroke-divider-rest',
                    },
                ],
            },
        ],
    },
    {
        title: 'Layer',
        subcategories: [
            {
                title: 'Neutral Layers',
                tokens: [
                    {
                        name: 'neutralLayer1',
                        cssProperty: '--neutral-layer-1',
                    },
                    {
                        name: 'neutralLayer2',
                        cssProperty: '--neutral-layer-2',
                    },
                    {
                        name: 'neutralLayer3',
                        cssProperty: '--neutral-layer-3',
                    },
                    {
                        name: 'neutralLayer4',
                        cssProperty: '--neutral-layer-4',
                    },
                ],
            },
            {
                title: 'Neutral Layer Card Container',
                tokens: [
                    {
                        name: 'neutralLayerCardContainer',
                        cssProperty: '--neutral-layer-card-container',
                    },
                ],
            },
            {
                title: 'Neutral Fill Layer',
                tokens: [
                    {
                        name: 'neutralFillLayerRest',
                        cssProperty: '--neutral-fill-layer-rest',
                    },
                ],
            },
            {
                title: 'Neutral Layer Floating',
                tokens: [
                    {
                        name: 'neutralLayerFloating',
                        cssProperty: '--neutral-layer-floating',
                    },
                ],
            },
        ],
    },
];
const ColorRowTemplate = html `
  <div class="row">
    <div
      class="preview"
      style="background-color: ${(x) => fastComponents[x.name].createCSS()}"
    ></div>
    <!-- <div class="token-name" title=${(x) => x.cssProperty}>${(x) => x.cssProperty}</div> -->
    <div class="token-name" title=${(x) => x.cssProperty}>${(x) => x.name}</div>
    <div>
      ${(x, c) => fastComponents[x.name]
    .getValueFor(c.parentContext.parentContext.parent.provider)
    .toColorString()
    .toUpperCase()}
    </div>
  </div>
`;
export const ColorTemplate = html `
  <div class="container" ${ref('provider')}>
    ${repeat(() => categories, html `
        <div class="column">
          <h3 class="header-title">${(x) => x.title}</h3>
          ${repeat((x) => x.subcategories, html `
              <h4>${(x) => x.title}</h4>
              ${repeat((x) => x.tokens, ColorRowTemplate)}
            `)}
        </div>
      `)}
  </div>
`;
